@@ -46,10 +46,10 @@ EXCLUDE_LOGINS=["/sbin/nologin", "/bin/false"]
 
 # Python 2/3 wrapper
 def getstatusoutput_wrapper(cmd):
-    if sys.version_info.major is 2:
+    if sys.version_info.major == 2:
         import commands
         return commands.getstatusoutput(cmd)
-    elif sys.version_info.major is 3:
+    elif sys.version_info.major == 3:
         import subprocess
         return subprocess.getstatusoutput(cmd)
     else:
@@ -486,9 +486,5 @@ try:
 	selconf=selinuxConfig(directory, setype, usepwd)
 	selconf.write()
 
-except getopt.error as error:
-	errorExit("Options Error " + error)
-except ValueError as error:
-	errorExit("ValueError " + error)
-except IndexError:
-	errorExit("IndexError")
+except Exception as error:
+	errorExit(error)
